@@ -1,7 +1,7 @@
 package HTML::DOM::Interface;
 
 use Exporter 5.57 'import';
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 =head1 NAME
 
@@ -97,6 +97,7 @@ gory details, look at the source code. In fact, here it is:
   	'HTML::DOM::Text' => 'Text',
   	'HTML::DOM::Comment' => 'Comment',
   	'HTML::DOM::Element' => 'HTMLElement',
+  	'HTML::DOM::TreeBuilder' => 'HTMLElement',
   	'HTML::DOM::Element::HTML' => 'HTMLHtmlElement',
   	'HTML::DOM::Element::Head' => 'HTMLHeadElement',
   	'HTML::DOM::Element::Link' => 'HTMLLinkElement',
@@ -140,6 +141,15 @@ gory details, look at the source code. In fact, here it is:
   	'HTML::DOM::Element::Map' => 'HTMLMapElement',
   	'HTML::DOM::Element::Area' => 'HTMLAreaElement',
   	'HTML::DOM::Element::Script' => 'HTMLScriptElement',
+  	'HTML::DOM::Element::Table' => 'HTMLTableElement',
+  	'HTML::DOM::Element::Caption' => 'HTMLTableCaptionElement',
+  	'HTML::DOM::Element::TableColumn' => 'HTMLTableColElement',
+  	'HTML::DOM::Element::TableSection' => 'HTMLTableSectionElement',
+  	'HTML::DOM::Element::TR' => 'HTMLTableRowElement',
+  	'HTML::DOM::Element::TableCell' => 'HTMLTableCellElement',
+  	'HTML::DOM::Element::FrameSet' => 'HTMLFrameSetElement',
+  	'HTML::DOM::Element::Frame' => 'HTMLFrameElement',
+  	'HTML::DOM::Element::IFrame' => 'HTMLIFrameElement',
   	'HTML::DOM::NodeList' => 'NodeList',
   	'HTML::DOM::NodeList::Radio' => 'NodeList',
   	'HTML::DOM::NodeList::Magic' => 'NodeList',
@@ -149,6 +159,7 @@ gory details, look at the source code. In fact, here it is:
   	'HTML::DOM::Collection::Elements' => 'HTMLCollection',
   	'HTML::DOM::Collection::Options' => 'HTMLCollection',
   	'HTML::DOM::Event' => 'Event',
+  	'HTML::DOM::View' => 'AbstractView',
   	 DOMException => {
   		_constants => [qw[
   			HTML::DOM::Exception::INDEX_SIZE_ERR
@@ -161,6 +172,11 @@ gory details, look at the source code. In fact, here it is:
   			HTML::DOM::Exception::NOT_FOUND_ERR
   			HTML::DOM::Exception::NOT_SUPPORTED_ERR
   			HTML::DOM::Exception::INUSE_ATTRIBUTE_ERR
+  			HTML::DOM::Exception::INVALID_STATE_ERR
+  			HTML::DOM::Exception::SYNTAX_ERR
+  			HTML::DOM::Exception::INVALID_MODIFICATION_ERR
+  			HTML::DOM::Exception::NAMESPACE_ERR
+  			HTML::DOM::Exception::INVALID_ACCESS_ERR
   			HTML::DOM::Exception::UNSPECIFIED_EVENT_TYPE_ERR
   		]],
   	 },
@@ -168,11 +184,9 @@ gory details, look at the source code. In fact, here it is:
 		_hash => 0,
 		_array => 0,
   		hasFeature => METHOD | BOOL,
-  	 },
-  	 DocumentFragment => {
-		_isa => 'Node',
-		_hash => 0,
-		_array => 0,
+  #		createDocumentType => METHOD | OBJ,
+  #		createDocument => METHOD | OBJ,
+  #		createCSSStyleSheet => METHOD | OBJ,
   	 },
   	 Node => {
 		_hash => 0,
@@ -208,6 +222,12 @@ gory details, look at the source code. In fact, here it is:
   		appendChild => METHOD | OBJ,
   		hasChildNodes => METHOD | BOOL,
   		cloneNode => METHOD | OBJ,
+  		normalize => METHOD | VOID,
+  		isSupported => METHOD | BOOL,
+  		namespaceURI => STR | READONLY,
+  		prefix => STR,
+  		localName => STR | READONLY,
+  		hasAttributes => METHOD | BOOL,
   		addEventListener => METHOD | VOID,
   		removeEventListener => METHOD | VOID,
   		dispatchEvent => METHOD | BOOL,
@@ -226,6 +246,9 @@ gory details, look at the source code. In fact, here it is:
   		removeNamedItem => METHOD | OBJ,
   		item => METHOD | OBJ,
   		length => NUM | READONLY,
+  #		getNamedItemNS => METHOD | OBJ,
+  #		setNamedItemNS => METHOD | OBJ,
+  #		removeNamedItemNS => METHOD | OBJ,
   	 },
   	 CharacterData => {
 		_isa => 'Node',
@@ -246,6 +269,7 @@ gory details, look at the source code. In fact, here it is:
   		name => STR | READONLY,
   		specified => BOOL | READONLY,
   		value => STR,
+  		ownerElement => OBJ | READONLY,
   	 },
   	 Text => {
 		_isa => 'CharacterData',
@@ -258,6 +282,11 @@ gory details, look at the source code. In fact, here it is:
 		_hash => 0,
 		_array => 0,
   	 },
+  	 DocumentFragment => {
+		_isa => 'Node',
+		_hash => 0,
+		_array => 0,
+  	 },
   	 HTMLCollection => {
 		_hash => 1,
 		_array => 1,
@@ -267,7 +296,7 @@ gory details, look at the source code. In fact, here it is:
   	 },
   	 HTMLDocument => {
   		doctype => OBJ | READONLY,
-		_hash => 0,
+		_hash => 1,
 		_array => 0,
   		implementation => OBJ | READONLY,
   		documentElement => OBJ | READONLY,
@@ -280,6 +309,11 @@ gory details, look at the source code. In fact, here it is:
   		createAttribute => METHOD | OBJ,
   		createEntityReference => METHOD | OBJ,
   		getElementsByTagName => METHOD | OBJ,
+  		importNode => METHOD | OBJ,
+  #		createElementNS => METHOD | OBJ,
+  #		createAttributeNS => METHOD | OBJ,
+  #		getElementsByTagNameNS => METHOD | OBJ,
+  		getElementById => METHOD | OBJ,
 		_isa => 'Node',
   		title => STR,
   		referrer => STR | READONLY,
@@ -299,6 +333,8 @@ gory details, look at the source code. In fact, here it is:
   		getElementById => METHOD | OBJ,
   		getElementsByName => METHOD | OBJ,
   		createEvent => METHOD | OBJ,
+  		defaultView => OBJ | READONLY,
+  #		styleSheets => OBJ | READONLY,
   	 },
   	 HTMLElement => {
   		tagName => STR | READONLY,
@@ -311,13 +347,21 @@ gory details, look at the source code. In fact, here it is:
   		setAttributeNode => METHOD | OBJ,
   		removeAttributeNode => METHOD | OBJ,
   		getElementsByTagName => METHOD | OBJ,
-  		normalize => METHOD | VOID,
+  #		getAttributeNS => METHOD | STR,
+  #		setAttributeNS => METHOD | VOID,
+  #		removeAttributeNS => METHOD | VOID,
+  #		getAttributeNodeNS => METHOD | OBJ,
+  #		setAttributeNodeNS => METHOD | OBJ,
+  #		getElementsByTagNameNS => METHOD | OBJ,
+  		hasAttribute => METHOD | BOOL,
+  #		hasAttributeNS => METHOD | BOOL,
 		_isa => 'Node',
   		id => STR,
   		title => STR,
   		lang => STR,
   		dir => STR,
   		className => STR,
+  		style => OBJ | READONLY,
   	 },
   	 HTMLHtmlElement => {
 		_isa => 'HTMLElement',
@@ -344,6 +388,7 @@ gory details, look at the source code. In fact, here it is:
   		rev => STR,
   		target => STR,
   		type => STR,
+  #		sheet => OBJ | READONLY,
   	 },
   	 HTMLTitleElement => {
 		_isa => 'HTMLElement',
@@ -406,7 +451,7 @@ gory details, look at the source code. In fact, here it is:
   		method => STR,
   		target => STR,
   		submit => METHOD | VOID,
-  #		reset => METHOD | VOID,
+  		reset => METHOD | VOID,
   	 },
   	 HTMLSelectElement => {
 		_isa => 'HTMLElement',
@@ -753,6 +798,132 @@ gory details, look at the source code. In fact, here it is:
   		src => STR,
   		type => STR,
   	 },
+  	 HTMLTableElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		caption => OBJ,
+  		tHead => OBJ,
+  		tFoot => OBJ,
+  		rows => OBJ | READONLY,
+  		tBodies => OBJ | READONLY,
+  		align => STR,
+  		bgColor => STR,
+  		border => STR,
+  		cellPadding => STR,
+  		cellSpacing => STR,
+  		frame => STR,
+  		rules => STR,
+  		summary => STR,
+  		width => STR,
+  		createTHead => METHOD | OBJ,
+  		deleteTHead => METHOD | VOID,
+  		createTFoot => METHOD | OBJ,
+  		deleteTFoot => METHOD | VOID,
+  		createCaption => METHOD | OBJ,
+  		deleteCaption => METHOD | VOID,
+  		insertRow => METHOD | OBJ,
+  		deleteRow => METHOD | VOID,
+  	 },
+  	 HTMLTableCaptionElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		align => STR,
+  	 },
+  	 HTMLTableColElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		align => STR,
+  		ch => STR,
+  		chOff => STR,
+  		span => NUM,
+  		vAlign => STR,
+  		width => STR,
+  	 },
+  	 HTMLTableSectionElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		align => STR,
+  		ch => STR,
+  		chOff => STR,
+  		vAlign => STR,
+  		rows => OBJ | READONLY,
+  		insertRow => METHOD | OBJ,
+  		deleteRow => METHOD | VOID,
+  	 },
+  	 HTMLTableRowElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		rowIndex => NUM,
+  		sectionRowIndex => NUM,
+  		cells => OBJ,
+  		align => STR,
+  		bgColor => STR,
+  		ch => STR,
+  		chOff => STR,
+  		vAlign => STR,
+  		insertCell => METHOD | OBJ,
+  		deleteCell => METHOD | VOID,
+  	 },
+  	 HTMLTableCellElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		cellIndex => NUM,
+  		abbr => STR,
+  		align => STR,
+  		axis => STR,
+  		bgColor => STR,
+  		ch => STR,
+  		chOff => STR,
+  		colSpan => NUM,
+  		headers => STR,
+  		height => STR,
+  		noWrap => BOOL,
+  		rowSpan => NUM,
+  		scope => STR,
+  		vAlign => STR,
+  		width => STR,
+  	 },
+  	 HTMLFrameSetElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		cols => STR,
+  		rows => STR,
+  	 },
+  	 HTMLFrameElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		frameBorder => STR,
+  		longDesc => STR,
+  		marginHeight => STR,
+  		marginWidth => STR,
+  		name => STR,
+  		noResize => BOOL,
+  		scrolling => STR,
+  		src => STR,
+  	 },
+  	 HTMLIFrameElement => {
+		_isa => 'HTMLElement',
+		_hash => 0,
+		_array => 0,
+  		align => STR,
+  		frameBorder => STR,
+  		height => STR,
+  		longDesc => STR,
+  		marginHeight => STR,
+  		marginWidth => STR,
+  		name => STR,
+  		scrolling => STR,
+  		src => STR,
+  		width => STR,
+  	 },
   	 Event => {
 		_hash => 0,
 		_array => 0,
@@ -772,6 +943,11 @@ gory details, look at the source code. In fact, here it is:
   		preventDefault => METHOD | VOID,
   		initEvent => METHOD | VOID,
   	 },
+  	 AbstractView => {
+		_hash => 0,
+		_array => 0,
+  		document => OBJ | READONLY,
+  	 },
   );
 
 __END__
